==> haskell-x509-validation-1.6.3-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509-validation/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.3
id: x509-validation-1.6.3-0f89d8d374c48b8a0db3a2a9867fa82f
key: x509v_1BwVZ4byygm0I96tpzIzW9
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-validation-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-validation-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-validation-1.6.3
hs-libraries: HSx509-validation-1.6.3-1BwVZ4byygm0I96tpzIzW9
depends:
    asn1-encoding-0.9.3-61b8646033da9bb10b3d5eef2c9988e8
    asn1-types-0.3.2-373d90c7a1b36e8b9d0fe76023835d30
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.10-0b27873a24b130f970d262828e1e69fa
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    hourglass-0.2.9-d44f07201da9fd2656b62ae800dd5aa9
    memory-0.11-3a745e41fe78387f608c420e9b455d25
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    x509-1.6.3-88141428fd098325953c29fe36fd878e
    x509-store-1.6.1-43770428c1088301ba6ed013a258fa1c
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.3-10-armv7h.pkg.tar.xz: usr/share/haskell/haskell-x509-validation/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.3
id: x509-validation-1.6.3-47849fe369535aae4a3b7e2d99568d36
key: x509v_DTPtGBonFKtJPK04pgH1Vm
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/x509-validation-1.6.3
library-dirs: /usr/lib/ghc-7.10.3/site-local/x509-validation-1.6.3
data-dir: /usr/share/arm-linux-ghc-7.10.3/x509-validation-1.6.3
hs-libraries: HSx509-validation-1.6.3-DTPtGBonFKtJPK04pgH1Vm
depends:
    asn1-encoding-0.9.3-973a6b8f38afc857f3a60ad311c8ee45
    asn1-types-0.3.2-3969820adc8283f126affe054010f830
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
    memory-0.11-3a745e41fe78387f608c420e9b455d25
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    pem-0.2.2-5f6df2ca3b7f68abc9010881cb82b5dd
    x509-1.6.3-9c5cbae50b7250847fc648c7f7d122e6
    x509-store-1.6.1-741461c55f7edc5697c99a37f0436ee6
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
